@@ -13,6 +13,8 @@ Note: These test cases are *not* included in the main test suite, as including
 import os
 import os.path
 import re
+import subprocess
+from subprocess import PIPE
 import sys
 from tempfile import TemporaryDirectory
 
@@ -23,7 +25,7 @@ from typing import List
 from mypy.defaults import PYTHON3_VERSION
 from mypy.test.config import test_temp_dir
 from mypy.test.data import DataDrivenTestCase, DataSuite
-from mypy.test.helpers import assert_string_arrays_equal, run_command
+from mypy.test.helpers import assert_string_arrays_equal, split_lines
 from mypy.util import try_find_python2_interpreter
 from mypy import api
 
@@ -55,6 +57,7 @@ def test_python_evaluation(testcase: DataDrivenTestCase, cache_dir: str) -> None
         '--no-site-packages',
         '--no-strict-optional',
         '--no-silence-site-packages',
+        '--no-error-summary',
     ]
     py2 = testcase.name.lower().endswith('python2')
     if py2:
@@ -85,13 +88,19 @@ def test_python_evaluation(testcase: DataDrivenTestCase, cache_dir: str) -> None
         if line.startswith(test_temp_dir + os.sep):
             output.append(line[len(test_temp_dir + os.sep):].rstrip("\r\n"))
         else:
+            # Normalize paths so that the output is the same on Windows and Linux/macOS.
+            line = line.replace(test_temp_dir + os.sep, test_temp_dir + '/')
             output.append(line.rstrip("\r\n"))
     if returncode == 0:
         # Execute the program.
-        returncode, interp_out = run_command([interpreter, program])
-        output.extend(interp_out)
+        proc = subprocess.run([interpreter, '-Wignore', program],
+                              cwd=test_temp_dir, stdout=PIPE, stderr=PIPE)
+        output.extend(split_lines(proc.stdout, proc.stderr))
     # Remove temp file.
     os.remove(program_path)
+    for i, line in enumerate(output):
+        if os.path.sep + 'typeshed' + os.path.sep in line:
+            output[i] = line.split(os.path.sep)[-1]
     assert_string_arrays_equal(adapt_output(testcase), output,
                                'Invalid output ({}, line {})'.format(
                                    testcase.file, testcase.line))
