@@ -5,23 +5,29 @@ from collections import OrderedDict
 from mypy.nodes import Var
 from mypy.test.helpers import assert_string_arrays_equal
 
-from mypyc.ops import (
-    Environment, BasicBlock, FuncIR, RuntimeArg, Goto, Return, LoadInt, Assign,
-    IncRef, DecRef, Branch, Call, Unbox, Box, RTuple, TupleGet, GetAttr, PrimitiveOp,
-    RegisterOp, FuncDecl,
-    ClassIR, RInstance, SetAttr, Op, Value, int_rprimitive, bool_rprimitive,
-    list_rprimitive, dict_rprimitive, object_rprimitive, FuncSignature,
+from mypyc.ir.ops import (
+    Environment, BasicBlock, Goto, Return, LoadInt, Assign, IncRef, DecRef, Branch,
+    Call, Unbox, Box, TupleGet, GetAttr, PrimitiveOp, RegisterOp,
+    SetAttr, Op, Value
 )
-from mypyc.genopsvtable import compute_vtable
-from mypyc.emit import Emitter, EmitterContext
-from mypyc.emitfunc import generate_native_function, FunctionEmitterVisitor
-from mypyc.ops_primitive import binary_ops
-from mypyc.ops_misc import none_object_op, true_op, false_op
-from mypyc.ops_list import (
+from mypyc.ir.rtypes import (
+    RTuple, RInstance, int_rprimitive, bool_rprimitive, list_rprimitive,
+    dict_rprimitive, object_rprimitive
+)
+from mypyc.ir.func_ir import FuncIR, FuncDecl, RuntimeArg, FuncSignature
+from mypyc.ir.class_ir import ClassIR
+from mypyc.irbuild.vtable import compute_vtable
+from mypyc.codegen.emit import Emitter, EmitterContext
+from mypyc.codegen.emitfunc import generate_native_function, FunctionEmitterVisitor
+from mypyc.primitives.registry import binary_ops
+from mypyc.primitives.misc_ops import none_object_op, true_op, false_op
+from mypyc.primitives.list_ops import (
     list_len_op, list_get_item_op, list_set_item_op, new_list_op, list_append_op
 )
-from mypyc.ops_dict import new_dict_op, dict_update_op, dict_get_item_op, dict_set_item_op
-from mypyc.ops_int import int_neg_op
+from mypyc.primitives.dict_ops import (
+    new_dict_op, dict_update_op, dict_get_item_op, dict_set_item_op
+)
+from mypyc.primitives.int_ops import int_neg_op
 from mypyc.subtype import is_subtype
 from mypyc.namegen import NameGenerator
 
@@ -91,16 +97,6 @@ class TestFunctionEmitterVisitor(unittest.TestCase):
             '-', self.n, self.m, self.k,
             "cpy_r_r0 = CPyTagged_Subtract(cpy_r_m, cpy_r_k);")
 
-    def test_list_repeat(self) -> None:
-        self.assert_emit_binary_op(
-            '*', self.ll, self.l, self.n,
-            """Py_ssize_t __tmp1;
-               __tmp1 = CPyTagged_AsSsize_t(cpy_r_n);
-               if (__tmp1 == -1 && PyErr_Occurred())
-                   CPyError_OutOfMemory();
-               cpy_r_r0 = PySequence_Repeat(cpy_r_l, __tmp1);
-            """)
-
     def test_int_neg(self) -> None:
         self.assert_emit(PrimitiveOp([self.m], int_neg_op, 55),
                          "cpy_r_r0 = CPyTagged_Negate(cpy_r_m);")
@@ -194,12 +190,23 @@ class TestFunctionEmitterVisitor(unittest.TestCase):
     def test_get_attr(self) -> None:
         self.assert_emit(
             GetAttr(self.r, 'y', 1),
-            """cpy_r_r0 = native_A_gety((mod___AObject *)cpy_r_r); /* y */""")
+            """cpy_r_r0 = ((mod___AObject *)cpy_r_r)->_y;
+               if (unlikely(((mod___AObject *)cpy_r_r)->_y == CPY_INT_TAG)) {
+                   PyErr_SetString(PyExc_AttributeError, "attribute 'y' of 'A' undefined");
+               } else {
+                   CPyTagged_IncRef(((mod___AObject *)cpy_r_r)->_y);
+               }
+            """)
 
     def test_set_attr(self) -> None:
         self.assert_emit(
             SetAttr(self.r, 'y', self.m, 1),
-            "cpy_r_r0 = native_A_sety((mod___AObject *)cpy_r_r, cpy_r_m); /* y */")
+            """if (((mod___AObject *)cpy_r_r)->_y != CPY_INT_TAG) {
+                   CPyTagged_DecRef(((mod___AObject *)cpy_r_r)->_y);
+               }
+               ((mod___AObject *)cpy_r_r)->_y = cpy_r_m;
+               cpy_r_r0 = 1;
+            """)
 
     def test_dict_get_item(self) -> None:
         self.assert_emit(PrimitiveOp([self.d, self.o2], dict_get_item_op, 1),
